<?php

namespace Litecms\Search\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Search\Http\Requests\ProductCustomSearchresultRequest;
use Litecms\Search\Interfaces\ProductCustomSearchresultRepositoryInterface;
use Litecms\Search\Models\ProductCustomSearchresult;

/**
 * Resource controller class for product_custom_searchresult.
 */
class ProductCustomSearchresultResourceController extends BaseController
{

    /**
     * Initialize product_custom_searchresult resource controller.
     *
     * @param type ProductCustomSearchresultRepositoryInterface $product_custom_searchresult
     *
     * @return null
     */
    public function __construct(ProductCustomSearchresultRepositoryInterface $product_custom_searchresult)
    {
        parent::__construct();
        $this->repository = $product_custom_searchresult;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Search\Repositories\Criteria\ProductCustomSearchresultResourceCriteria::class);
    }

    /**
     * Display a list of product_custom_searchresult.
     *
     * @return Response
     */
    public function index(ProductCustomSearchresultRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Search\Repositories\Presenter\ProductCustomSearchresultPresenter::class)
                ->$function();
        }

        $product_custom_searchresults = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('search::product_custom_searchresult.names'))
            ->view('search::product_custom_searchresult.index', true)
            ->data(compact('product_custom_searchresults', 'view'))
            ->output();
    }

    /**
     * Display product_custom_searchresult.
     *
     * @param Request $request
     * @param Model   $product_custom_searchresult
     *
     * @return Response
     */
    public function show(ProductCustomSearchresultRequest $request, ProductCustomSearchresult $product_custom_searchresult)
    {

        if ($product_custom_searchresult->exists) {
            $view = 'search::product_custom_searchresult.show';
        } else {
            $view = 'search::product_custom_searchresult.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('search::product_custom_searchresult.name'))
            ->data(compact('product_custom_searchresult'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new product_custom_searchresult.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProductCustomSearchresultRequest $request)
    {

        $product_custom_searchresult = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('search::product_custom_searchresult.name')) 
            ->view('search::product_custom_searchresult.create', true) 
            ->data(compact('product_custom_searchresult'))
            ->output();
    }

    /**
     * Create new product_custom_searchresult.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProductCustomSearchresultRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $product_custom_searchresult                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('search::product_custom_searchresult.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('search/product_custom_searchresult/' . $product_custom_searchresult->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/search/product_custom_searchresult'))
                ->redirect();
        }

    }

    /**
     * Show product_custom_searchresult for editing.
     *
     * @param Request $request
     * @param Model   $product_custom_searchresult
     *
     * @return Response
     */
    public function edit(ProductCustomSearchresultRequest $request, ProductCustomSearchresult $product_custom_searchresult)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('search::product_custom_searchresult.name'))
            ->view('search::product_custom_searchresult.edit', true)
            ->data(compact('product_custom_searchresult'))
            ->output();
    }

    /**
     * Update the product_custom_searchresult.
     *
     * @param Request $request
     * @param Model   $product_custom_searchresult
     *
     * @return Response
     */
    public function update(ProductCustomSearchresultRequest $request, ProductCustomSearchresult $product_custom_searchresult)
    {
        try {
            $attributes = $request->all();

            $product_custom_searchresult->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('search::product_custom_searchresult.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('search/product_custom_searchresult/' . $product_custom_searchresult->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('search/product_custom_searchresult/' . $product_custom_searchresult->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the product_custom_searchresult.
     *
     * @param Model   $product_custom_searchresult
     *
     * @return Response
     */
    public function destroy(ProductCustomSearchresultRequest $request, ProductCustomSearchresult $product_custom_searchresult)
    {
        try {

            $product_custom_searchresult->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('search::product_custom_searchresult.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('search/product_custom_searchresult/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('search/product_custom_searchresult/' . $product_custom_searchresult->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple product_custom_searchresult.
     *
     * @param Model   $product_custom_searchresult
     *
     * @return Response
     */
    public function delete(ProductCustomSearchresultRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('search::product_custom_searchresult.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('search/product_custom_searchresult'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/search/product_custom_searchresult'))
                ->redirect();
        }

    }

    /**
     * Restore deleted product_custom_searchresults.
     *
     * @param Model   $product_custom_searchresult
     *
     * @return Response
     */
    public function restore(ProductCustomSearchresultRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('search::product_custom_searchresult.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/search/product_custom_searchresult'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/search/product_custom_searchresult/'))
                ->redirect();
        }

    }

}
