<?php

namespace Litecms\Search\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Search\Http\Requests\ProductCustomSearchresultRequest;
use Litecms\Search\Models\ProductCustomSearchresult;

/**
 * Admin web controller class.
 */
class ProductCustomSearchresultWorkflowController extends BaseController
{

    /**
     * Workflow controller function for product_custom_searchresult.
     *
     * @param Model   $product_custom_searchresult
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ProductCustomSearchresultRequest $request, ProductCustomSearchresult $product_custom_searchresult, $step)
    {

        try {

            $product_custom_searchresult->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('search::product_custom_searchresult.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/product_custom_searchresult/product_custom_searchresult/' . $product_custom_searchresult->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/product_custom_searchresult/product_custom_searchresult/' . $product_custom_searchresult->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for product_custom_searchresult.
     *
     * @param Model   $product_custom_searchresult
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(ProductCustomSearchresult $product_custom_searchresult, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $product_custom_searchresult->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('search::product_custom_searchresult.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('search::admin.product_custom_searchresult.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('search::admin.product_custom_searchresult.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('search::admin.product_custom_searchresult.message', $data)->render();

        }

    }
}
