<?php

namespace Litecms\Search\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Search\Models\ProductCustomSearchresult;

class ProductCustomSearchresultPolicy
{

    /**
     * Determine if the given user can view the product_custom_searchresult.
     *
     * @param UserPolicy $user
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProductCustomSearchresult $product_custom_searchresult)
    {
        if ($user->canDo('search.product_custom_searchresult.view') && $user->isAdmin()) {
            return true;
        }

        return $product_custom_searchresult->user_id == user_id() && $product_custom_searchresult->user_type == user_type();
    }

    /**
     * Determine if the given user can create a product_custom_searchresult.
     *
     * @param UserPolicy $user
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('search.product_custom_searchresult.create');
    }

    /**
     * Determine if the given user can update the given product_custom_searchresult.
     *
     * @param UserPolicy $user
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProductCustomSearchresult $product_custom_searchresult)
    {
        if ($user->canDo('search.product_custom_searchresult.edit') && $user->isAdmin()) {
            return true;
        }

        return $product_custom_searchresult->user_id == user_id() && $product_custom_searchresult->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given product_custom_searchresult.
     *
     * @param UserPolicy $user
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProductCustomSearchresult $product_custom_searchresult)
    {
        return $product_custom_searchresult->user_id == user_id() && $product_custom_searchresult->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given product_custom_searchresult.
     *
     * @param UserPolicy $user
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProductCustomSearchresult $product_custom_searchresult)
    {
        if ($user->canDo('search.product_custom_searchresult.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product_custom_searchresult.
     *
     * @param UserPolicy $user
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProductCustomSearchresult $product_custom_searchresult)
    {
        if ($user->canDo('search.product_custom_searchresult.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
