<?php

namespace Litecms\Search\Workflow;

use Litecms\Search\Models\ProductCustomSearchresult;
use Validator;

class ProductCustomSearchresultValidator
{

    /**
     * Determine if the given product_custom_searchresult is valid for complete status.
     *
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool / Validator
     */
    public function complete(ProductCustomSearchresult $product_custom_searchresult)
    {
        return Validator::make($product_custom_searchresult->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given product_custom_searchresult is valid for verify status.
     *
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool / Validator
     */
    public function verify(ProductCustomSearchresult $product_custom_searchresult)
    {
        return Validator::make($product_custom_searchresult->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given product_custom_searchresult is valid for approve status.
     *
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool / Validator
     */
    public function approve(ProductCustomSearchresult $product_custom_searchresult)
    {
        return Validator::make($product_custom_searchresult->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given product_custom_searchresult is valid for publish status.
     *
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool / Validator
     */
    public function publish(ProductCustomSearchresult $product_custom_searchresult)
    {
        return Validator::make($product_custom_searchresult->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given product_custom_searchresult is valid for archive status.
     *
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool / Validator
     */
    public function archive(ProductCustomSearchresult $product_custom_searchresult)
    {
        return Validator::make($product_custom_searchresult->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given product_custom_searchresult is valid for unpublish status.
     *
     * @param ProductCustomSearchresult $product_custom_searchresult
     *
     * @return bool / Validator
     */
    public function unpublish(ProductCustomSearchresult $product_custom_searchresult)
    {
        return Validator::make($product_custom_searchresult->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
